@@ -66,7 +66,7 @@ def normalize_client_error(err):
 
 def worker(queue, mode):
     try:
-        s3 = get_authenticated_boto3_session().client('s3')
+        s3 = get_authenticated_boto3_client('s3')
         while True:
             url = queue.get()
             if url is None:
@@ -163,7 +163,7 @@ class S3Ops(object):
 
     def reset_client(self, hard_reset=False):
         if hard_reset or self.s3 is None:
-            self.s3 = get_authenticated_boto3_session().client('s3')
+            self.s3 = get_authenticated_boto3_client('s3')
 
     @aws_retry
     def get_size(self, url):
@@ -529,6 +529,6 @@ def get(prefixes,
                 print(format_triplet(url.prefix, url.url, url.local))
 
 if __name__ == '__main__':
-    from metaflow.metaflow_config import get_authenticated_boto3_session
+    from metaflow.metaflow_config import get_authenticated_boto3_client
     from botocore.exceptions import ClientError
     cli(auto_envvar_prefix='S3OP')
\ No newline at end of file
