@@ -1,9 +1,10 @@
+import os
 import requests
 import time
 
 from metaflow.exception import MetaflowException
-from metaflow.metaflow_config import update_var, get_var, \
-    METADATA_SERVICE_NUM_RETRIES, METADATA_SERVICE_HEADERS
+from metaflow.metaflow_config import METADATA_SERVICE_NUM_RETRIES, METADATA_SERVICE_HEADERS, \
+    METADATA_SERVICE_URL
 from .metadata import MetadataProvider
 
 
@@ -25,12 +26,16 @@ class ServiceMetadataProvider(MetadataProvider):
     @classmethod
     def compute_info(cls, val):
         v = val.rstrip('/')
-        update_var('METADATA_SERVICE_URL', v)
+        try:
+            resp = requests.get(os.path.join(v, 'ping'), headers=METADATA_SERVICE_HEADERS)
+            resp.raise_for_status()
+        except:  # noqa E722
+            raise ValueError('Could not ping Metaflow service at %s' % v)
         return v
 
     @classmethod
     def default_info(cls):
-        return get_var('METADATA_SERVICE_URL')
+        return METADATA_SERVICE_URL
 
     def new_run_id(self, tags=[], sys_tags=[]):
         return self._new_run(tags=tags, sys_tags=sys_tags)
@@ -173,7 +178,10 @@ class ServiceMetadataProvider(MetadataProvider):
 
     @classmethod
     def _request(cls, monitor, path, data=None):
-        url = '%s/%s' % (get_var('METADATA_SERVICE_URL'), path.lstrip('/'))
+        if cls.INFO is None:
+            raise MetaflowException('Cannot find URL for Metaflow service -- did you properly set '
+                                    'the METAFLOW_SERVICE_URL environment variable')
+        url = os.path.join(cls.INFO, path)
         for i in range(METADATA_SERVICE_NUM_RETRIES):
             try:
                 if data is None:
