@@ -6,12 +6,12 @@ import fcntl
 CONDA_MAGIC_FILE = 'conda.cnd'
 
 
-def get_conda_manifest_path(ds_root):
-    return os.path.join(ds_root, CONDA_MAGIC_FILE)
+def get_conda_manifest_path(ds_root, flow_name):
+    return os.path.join(ds_root, flow_name, CONDA_MAGIC_FILE)
 
 
-def read_conda_manifest(ds_root):
-    path = get_conda_manifest_path(ds_root)
+def read_conda_manifest(ds_root, flow_name):
+    path = get_conda_manifest_path(ds_root, flow_name)
     if os.path.exists(path) and os.path.getsize(path) > 0:
         with open(path) as f:
             return json.load(f)
@@ -19,8 +19,8 @@ def read_conda_manifest(ds_root):
         return {}
 
 
-def write_to_conda_manifest(ds_root, key, value):
-    path = get_conda_manifest_path(ds_root)
+def write_to_conda_manifest(ds_root, flow_name, key, value):
+    path = get_conda_manifest_path(ds_root, flow_name)
     try:
         os.makedirs(os.path.dirname(path))
     except OSError as x:
