@@ -12,23 +12,23 @@ from metaflow.metaflow_config import DATASTORE_LOCAL_DIR
 from . import CONDA_MAGIC_FILE
 
 
-def bootstrap_environment(env_id):
-    setup_conda_manifest()
-    packages = download_conda_packages(env_id)
+def bootstrap_environment(flow_name, env_id):
+    setup_conda_manifest(flow_name)
+    packages = download_conda_packages(flow_name, env_id)
     install_conda_environment(env_id, packages)
 
-def setup_conda_manifest():
-    manifest_folder = os.path.join(os.getcwd(), DATASTORE_LOCAL_DIR)
+def setup_conda_manifest(flow_name):
+    manifest_folder = os.path.join(os.getcwd(), DATASTORE_LOCAL_DIR, flow_name)
     if not os.path.exists(manifest_folder):
         os.makedirs(manifest_folder)
     shutil.move(os.path.join(os.getcwd(), CONDA_MAGIC_FILE), 
         os.path.join(manifest_folder, CONDA_MAGIC_FILE))
 
-def download_conda_packages(env_id):
+def download_conda_packages(flow_name, env_id):
     pkgs_folder = os.path.join(os.getcwd(), "pkgs")
     if not os.path.exists(pkgs_folder):
         os.makedirs(pkgs_folder)
-    manifest_folder = os.path.join(os.getcwd(), DATASTORE_LOCAL_DIR)
+    manifest_folder = os.path.join(os.getcwd(), DATASTORE_LOCAL_DIR, flow_name)
     with open(os.path.join(manifest_folder, CONDA_MAGIC_FILE)) as f:
         env = json.load(f)[env_id]
         with S3() as s3:
@@ -51,4 +51,4 @@ def install_conda_environment(env_id, packages):
     os.system(" && ".join(args))
 
 if __name__ == "__main__":
-    bootstrap_environment(sys.argv[1])
\ No newline at end of file
+    bootstrap_environment(sys.argv[1], sys.argv[2])
\ No newline at end of file
