@@ -53,14 +53,15 @@ class CondaEnvironment(MetaflowEnvironment):
         if env_id is not None:
             return [
                     "echo \'Bootstrapping environment.\'",
-                    "python -m metaflow.plugins.conda.batch_bootstrap %s" % env_id,
+                    "python -m metaflow.plugins.conda.batch_bootstrap \"%s\" %s" % \
+                        (self.flow.name, env_id),
                     "echo \'Environment bootstrapped.\'"
                 ]
         return []
 
     def add_to_package(self):
         # Add conda manifest file to job package at the top level.
-        path = get_conda_manifest_path(self.local_root)
+        path = get_conda_manifest_path(self.local_root, self.flow.name)
         if os.path.exists(path):
             return [(path, os.path.basename(path))]
         else:
