@@ -74,7 +74,7 @@ class CondaStepDecorator(StepDecorator):
 
     def _resolve_step_environment(self, ds_root, force=False):
         env_id = self._env_id()
-        cached_deps = read_conda_manifest(ds_root)
+        cached_deps = read_conda_manifest(ds_root, self.flow.name)
         if CondaStepDecorator.conda is None:
             CondaStepDecorator.conda = Conda()
         if force or env_id not in cached_deps or 'cache_urls' not in cached_deps[env_id]:
@@ -92,7 +92,7 @@ class CondaStepDecorator(StepDecorator):
                 payload = cached_deps[env_id]
             if self.datastore.TYPE == 's3' and 'cache_urls' not in payload:
                 payload['cache_urls'] = self._cache_env()
-            write_to_conda_manifest(ds_root, env_id, payload)
+            write_to_conda_manifest(ds_root, self.flow.name, env_id, payload)
         CondaStepDecorator.environments = CondaStepDecorator.conda.environments(self.flow.name)
         return env_id
 
@@ -115,7 +115,7 @@ class CondaStepDecorator(StepDecorator):
     def _prepare_step_environment(self, step_name, ds_root):
         env_id = self._resolve_step_environment(ds_root)
         if env_id not in CondaStepDecorator.environments:
-            cached_deps = read_conda_manifest(ds_root)
+            cached_deps = read_conda_manifest(ds_root, self.flow.name)
             self.conda.create(self.step,
                               env_id,
                               cached_deps[env_id]['urls'],
